cgexplore.molecular.SquarePrecursor
===================================

.. currentmodule:: cgexplore.molecular

.. autoclass:: SquarePrecursor
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~SquarePrecursor.get_building_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SquarePrecursor.present_beads
      ~SquarePrecursor.binder_beads
      ~SquarePrecursor.placer_beads
   
   